Documentation
¶
Index ¶
Constants ¶
const SdkSecretHeaderName = "Kobble-Sdk-Secret"
Variables ¶
This section is empty.
Functions ¶
func VerifyJwt ¶
func VerifyJwt(tokenString string, key *ecdsa.PublicKey, options VerifyJwtOptions) (map[string]any, error)
VerifyJwt verifies a JWT token string using the provided public key.
The options parameter allows you to specify which claims to verify. If the token is valid, the payload is returned as a map[string]any.
Types ¶
type Cache ¶
type Cache[T any] struct { // contains filtered or unexported fields }
func NewCache ¶
func NewCache[T any](config CacheConfig) *Cache[T]
type CacheConfig ¶
type ErrorBase ¶
func NewErrorBase ¶
type HttpClient ¶
type HttpClient struct {
// contains filtered or unexported fields
}
func NewHttpClient ¶
func NewHttpClient(config HttpClientConfig) *HttpClient
type HttpClientConfig ¶
type VerifyJwtError ¶
type VerifyJwtError struct {
Message string
}
func (*VerifyJwtError) Error ¶
func (e *VerifyJwtError) Error() string
Click to show internal directories.
Click to hide internal directories.